==> Banners-2.3.7.tar.gz: Banners/lang/ext/nb_NO.php <==
<?php
$lang['help_param_action'] = 'Oppgi oppf&oslash;rselen for modulen. Mulige verdier er &quot;default&quot; og &quot;list&quot;. default handlingen benyttes for &aring; vise et enkelt banner i forhold til spesifisert kriterie. list handlingen benyttes til &aring; vise alle bannere av en spesifisert kategori eller kategori id';
$lang['help_param_category'] = 'I standard handlingen, vil denne parameter bli benyttet for &aring; spesifisere navnet p&aring; kategorien hvor et enkelt banner skal vises fra. I list handlingen er denne parameter p&aring;krevd for &aring; spesifisere navnet p&aring; hvilken kategori alle bannerne skal vises fra';
$lang['help_param_mode'] = 'Denne parameter blir kun benyttet i standard handlingen, hvor den spesifiserer m&aring;ten som bannere blir valgt fra den spesifiserte kategorien. Den  eneste verdien er &quot;sequential&quot; som indikerer at modulen skal velge det neste ikke-utl&oslash;pte banneret som er minst vist. Ved &aring; ikke spesifisere denne parameter vil resultatet bli at et tilfeldig banner blir vist';
$lang['help_param_name'] = 'Denne parameter benyttes kun i default (standard) handlingen. Den spesifiserer et absolutt navn p&aring; et banner som skal lastes. Men, om banneret er ugyldig (at antall visninger har blitt n&aring;dd, ELLER det har utl&oslash;pt), ingenting vil bli vist.';
$lang['bannerlist_template'] = 'Banner listemal';
$lang['info_bannerlist_template'] = 'Om benyttet med list handlingen, vil denne mal kontrollere visningen av alle bannere i den valgte kattegorien';
$lang['none'] = 'Ingen';
$lang['error_invalid_dates'] = 'Feil! Ugyldige datoer';
$lang['editbanner'] = 'Rediger banner';
$lang['start_date'] = 'Startdato';
$lang['atttext'] = 'p&aring;';
$lang['template'] = 'Mal';
$lang['default_template'] = 'Standard kategorimal';
$lang['reset_template'] = 'Tilbakestill mal til standard';
$lang['error_banners'] = 'Ingen banner';
$lang['error_bannerexists'] = 'Banner med dette navnet eksisterer allerede';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk rettigheter.';
$lang['addbanner'] = 'Legg til banner';
$lang['addcategory'] = 'Legg til kategori';
$lang['areyousure'] = 'Er du sikker?';
$lang['banners'] = 'Bannere';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['category'] = 'Kategori';
$lang['created'] = 'Opprettet';
$lang['date'] = 'Dato';
$lang['delete'] = 'Slett';
$lang['description'] = 'Beskrivelse';
$lang['edit'] = 'Rediger';
$lang['editcategory'] = 'Rediger kategori';
$lang['error'] = 'Feil!';
$lang['error_banerexists'] = 'Banner med dette navnet eksisterer allerede';
$lang['error_categorynotempty'] = 'Feil: Kategorien er ikke tom!';
$lang['error_dberror'] = 'Feil: Databasefeil!';
$lang['error_emptybannername'] = 'Feil: Mangler Banner navn!';
$lang['error_emptycategory'] = 'Feil: Tom kategori!';
$lang['error_insufficientparams'] = 'Feil: Ikke nok informasjon!';
$lang['error_nocategories'] = 'Feil: Ingen kategori funnet!';
$lang['error_noresults'] = 'Ingen banner samsvarer med foresp&oslash;rsel';
$lang['error_textorimage'] = 'Oppgi URL og IMAGE eller TEXT, ikke begge';
$lang['expires'] = 'Utl&oslash;per';
$lang['friendlyname'] = 'Administrer bannere';
$lang['height'] = 'H&oslash;yde';
$lang['hits'] = 'Treff';
$lang['href_text'] = 'Link tekst';
$lang['id'] = 'ID ';
$lang['image'] = 'Bilde';
$lang['image_text'] = 'Alt. bilde tekst';
$lang['impressions'] = 'Innrykk';
$lang['info_href_text'] = 'Ekstra tekst for link taggen.  Denne tekst plasseres i link taggen bokstavelig talt';
$lang['info_image'] = 'Spesifiser en fil relativt til din opplastingsmappe';
$lang['info_image_text'] = 'Ekstra tekst for bilde taggen';
$lang['info_max_hits'] = 'Bruk 0 for ubegrensede treff';
$lang['info_max_impressions'] = 'Bruk 0 for ubegrensede innrykk';
$lang['installed'] = 'Modul versjon %s installert.';
$lang['ipaddress'] = 'IP adresse';
$lang['max_hits'] = 'Maksimum treff';
$lang['max_impressions'] = 'Maksimum innrykk';
$lang['name'] = 'Navn';
$lang['never'] = 'Aldri';
$lang['postinstall'] = 'Etter installasjons melding, f.eks. husk &aring; sette &quot;Manage Banners&quot; rettigheter for &aring; bruke denne modulen';
$lang['postuninstall'] = 'Banner modul avinstallert og alle database tabeller fjernet. Trist &aring; se deg g&aring;.';
$lang['preferences'] = 'Innstillinger';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['prompt_categorydesc'] = 'Kategori beskrivelse';
$lang['prompt_categoryname'] = 'Kategori navn';
$lang['prompt_imageheight'] = 'Bilde h&oslash;yde';
$lang['prompt_imagewidth'] = 'Bilde bredde';
$lang['prompt_subnet_exclusions'] = 'Ekskluder disse subnett fra all statistikk innhenting';
$lang['prompt_upload_category'] = 'Kategori (Opplastings modul)';
$lang['prompt_upload_file'] = 'Bilde (Opplastings modul)';
$lang['selectcategory'] = 'Velg kategori';
$lang['submit'] = 'Utf&oslash;r';
$lang['text'] = 'Tekst';
$lang['title_mod_admin'] = 'Modul administrasjonspanel';
$lang['title_mod_prefs'] = 'Modul innstillinger';
$lang['uninstalled'] = 'Modul avinstallert';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Bredde';
$lang['title_admin_panel'] = 'Banner modul';
$lang['moddescription'] = 'en modul for &aring; h&aring;ndtere roterende bannere';
$lang['welcome_text'] = '<p>Velkommen til Banner behandlings modulens administrasjons seksjon. </p>';
$lang['changelog'] = '<ul>
<li>Version 1.0. 6 August 2005. Initial Release.</li>
<li>Version 2.0. September 2005. Initial Release for 0.1..</li>
<li>Version 2.0.1. September 2005. Display sample banner in the edit banner page, added name= parameter, and made subnet exclusions work.  Also changed the definition of the database to allow for additional text in the link and image tags.</li>
<li>Version 2.0.2. September 2005. Added integration with the uploads module (1.0.6) so that we can get lits of files for banners, etc.  The banners module is still optional though.</li>
<li>Version 2.0.3. September 2005. Fixed a very minor issue with never expires..</li>
<li>Version 2.0.4. September 2005. Fixed a very minor issue with module dependencies, and a big bug in the database spec if you did a scratch install.</li>
<li>Version 2.0.5. October 2005. Add coments around the output</li>
<li>Version 2.0.6. December 2005. Minor validation fixes, description is now output between the <img>and</img> tags, and an alt attribute is in the img tag.</li>
<li>Version 2.0.7. January 2006. More validation fixes, Moved the admin tabs around, fixed an issue where you could almost create a banner without defining a category, and... fixed the expiry date issue for good (hopefully).</li>
<li>Version 2.1.0. August 2006. Prepared for 1.0 compatibility, split into multiple files, used references where possible, improved messages, and a general cleanup.</li>
<li>Version 2.2. March 2008. 
    <p>The first release in a long while this fixes issues with the date fields, and the expiry date.  Also integrates changes so that the active tab is maintaned (DeeEye) and changes the license.</p>
    <p>Now require CMS 1.2.3 or greater</p>
</li>
<li>Version 2.2.1. April 2008.
    <p>Minor fixes.</p>
</li>
<li>Version 2.2.3. April 2009.
    <p>Remove the width and height parameters, add a start date, and now use templates... major overhaul.</p>
</li>
<li>Version 2.3 - September 2009.
  <ul>
    <li>Major cleanup of code</li>
    <li>Get rid of the never expire stuff... people can just use a really long date.</li>
    <li>Dont ask for input of times any more... just use days</li>
    <li>Fixed to work with newest version of uploads, if it can be found.</li>
    <li>Now depends on CGExtensions</li>
    <li>Adds the banner list action.</li>
  </ul>
</li>
<li>Version 2.3.1 - September 2009.
  <ul>
    <li>Bug Fixes.</li>
  </ul>
</li>
<li>Version 2.3.2 - October 2009.
  <ul>
    <li>Minor Bug Fixes.</li>
  </ul>
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {Banners category=&quot;categoryname&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<p>You can also output a list of all of the valid banners within a category by specifying the action=&quot;list&quot; parameter on the tag.  See more information about this below.</p>
<h3>Hint</h3>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utmz'] = '156861353.1272675501.2656.57.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
$lang['utma'] = '156861353.179052623084110100.1210423577.1273079966.1273093045.2687';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.4.10.1273093045';
?>

==> Banners-2.5.1.tar.gz: Banners/lang/ext/nb_NO.php <==
<?php
$lang['your_ad_here'] = 'Din annonse kunne v&aelig;rt her';
$lang['prompt_dflt_image'] = 'Standard bilde';
$lang['prompt_dflt_url'] = 'Standard URL';
$lang['info_dflt_image'] = 'Angi et bildenavn (relativt til uploads katalogen) til et bilde som skal brukes n&aring;r ingen bannere er gyldige for visning';
$lang['prompt_hidefrombots'] = 'Utelukk robotter fra innrykk telling';
$lang['help_param_action'] = 'Oppgi oppf&oslash;rselen for modulen. Mulige verdier er &quot;default&quot; og &quot;list&quot;. default handlingen benyttes for &aring; vise et enkelt banner i forhold til spesifisert kriterie. list handlingen benyttes til &aring; vise alle bannere av en spesifisert kategori eller kategori id';
$lang['help_param_category'] = 'I standard handlingen, vil denne parameter bli benyttet for &aring; spesifisere navnet p&aring; kategorien hvor et enkelt banner skal vises fra. I list handlingen er denne parameter p&aring;krevd for &aring; spesifisere navnet p&aring; hvilken kategori alle bannerne skal vises fra';
$lang['help_param_mode'] = 'Denne parameter blir kun benyttet i standard handlingen, hvor den spesifiserer m&aring;ten som bannere blir valgt fra den spesifiserte kategorien. Den  eneste verdien er &quot;sequential&quot; som indikerer at modulen skal velge det neste ikke-utl&oslash;pte banneret som er minst vist. Ved &aring; ikke spesifisere denne parameter vil resultatet bli at et tilfeldig banner blir vist';
$lang['help_param_name'] = 'Denne parameter benyttes kun i default (standard) handlingen. Den spesifiserer et absolutt navn p&aring; et banner som skal lastes. Men, om banneret er ugyldig (at antall visninger har blitt n&aring;dd, ELLER det har utl&oslash;pt), ingenting vil bli vist.';
$lang['bannerlist_template'] = 'Banner listemal';
$lang['info_bannerlist_template'] = 'Om benyttet med list handlingen, vil denne mal kontrollere visningen av alle bannere i den valgte kattegorien';
$lang['none'] = 'Ingen';
$lang['error_invalid_dates'] = 'Feil! Ugyldige datoer';
$lang['editbanner'] = 'Rediger banner';
$lang['start_date'] = 'Startdato';
$lang['atttext'] = 'p&aring;';
$lang['template'] = 'Mal';
$lang['default_template'] = 'Standard kategorimal';
$lang['reset_template'] = 'Tilbakestill mal til standard';
$lang['error_banners'] = 'Ingen banner';
$lang['error_bannerexists'] = 'Banner med dette navnet eksisterer allerede';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk rettigheter.';
$lang['addbanner'] = 'Legg til banner';
$lang['addcategory'] = 'Legg til kategori';
$lang['areyousure'] = 'Er du sikker?';
$lang['banners'] = 'Bannere';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['category'] = 'Kategori';
$lang['created'] = 'Opprettet';
$lang['date'] = 'Dato';
$lang['delete'] = 'Slett';
$lang['description'] = 'Beskrivelse';
$lang['edit'] = 'Rediger';
$lang['editcategory'] = 'Rediger kategori';
$lang['error'] = 'Feil!';
$lang['error_banerexists'] = 'Banner med dette navnet eksisterer allerede';
$lang['error_categorynotempty'] = 'Feil: Kategorien er ikke tom!';
$lang['error_dberror'] = 'Feil: Databasefeil!';
$lang['error_emptybannername'] = 'Feil: Mangler Banner navn!';
$lang['error_emptycategory'] = 'Feil: Tom kategori!';
$lang['error_insufficientparams'] = 'Feil: Ikke nok informasjon!';
$lang['error_nocategories'] = 'Feil: Ingen kategori funnet!';
$lang['error_noresults'] = 'Ingen banner samsvarer med foresp&oslash;rsel';
$lang['error_textorimage'] = 'Oppgi URL og IMAGE eller TEXT, ikke begge';
$lang['expires'] = 'Utl&oslash;per';
$lang['friendlyname'] = 'Administrer bannere';
$lang['height'] = 'H&oslash;yde';
$lang['hits'] = 'Treff';
$lang['href_text'] = 'Link tekst';
$lang['id'] = 'ID ';
$lang['image'] = 'Bilde';
$lang['image_text'] = 'Alt. bilde tekst';
$lang['impressions'] = 'Innrykk';
$lang['info_href_text'] = 'Ekstra tekst for link taggen.  Denne tekst plasseres i link taggen bokstavelig talt';
$lang['info_image'] = 'Spesifiser en fil relativt til din opplastingsmappe';
$lang['info_image_text'] = 'Ekstra tekst for bilde taggen';
$lang['info_max_hits'] = 'Bruk 0 for ubegrensede treff';
$lang['info_max_impressions'] = 'Bruk 0 for ubegrensede innrykk';
$lang['installed'] = 'Modul versjon %s installert.';
$lang['ipaddress'] = 'IP adresse';
$lang['max_hits'] = 'Maksimum treff';
$lang['max_impressions'] = 'Maksimum innrykk';
$lang['name'] = 'Navn';
$lang['never'] = 'Aldri';
$lang['postinstall'] = 'Etter installasjons melding, f.eks. husk &aring; sette &quot;Manage Banners&quot; rettigheter for &aring; bruke denne modulen';
$lang['postuninstall'] = 'Banner modul avinstallert og alle database tabeller fjernet. Trist &aring; se deg g&aring;.';
$lang['preferences'] = 'Innstillinger';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['prompt_categorydesc'] = 'Kategori beskrivelse';
$lang['prompt_categoryname'] = 'Kategori navn';
$lang['prompt_imageheight'] = 'Bilde h&oslash;yde';
$lang['prompt_imagewidth'] = 'Bilde bredde';
$lang['prompt_subnet_exclusions'] = 'Ekskluder disse subnett fra all statistikk innhenting';
$lang['prompt_upload_category'] = 'Kategori (Opplastings modul)';
$lang['prompt_upload_file'] = 'Bilde (Opplastings modul)';
$lang['selectcategory'] = 'Velg kategori';
$lang['submit'] = 'Utf&oslash;r';
$lang['text'] = 'Tekst';
$lang['title_mod_admin'] = 'Modul administrasjonspanel';
$lang['title_mod_prefs'] = 'Modul innstillinger';
$lang['uninstalled'] = 'Modul avinstallert';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Bredde';
$lang['title_admin_panel'] = 'Banner modul';
$lang['moddescription'] = 'en modul for &aring; h&aring;ndtere roterende bannere';
$lang['welcome_text'] = '<p>Velkommen til Banner behandlings modulens administrasjons seksjon. </p>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {Banners category=&quot;categoryname&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<p>You can also output a list of all of the valid banners within a category by specifying the action=&quot;list&quot; parameter on the tag.  See more information about this below.</p>
<h3>Hint</h3>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utmz'] = '156861353.1296948797.3555.80.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['utma'] = '156861353.179052623084110100.1210423577.1297627188.1297629005.3583';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.3.10.1297629005';
?>
